@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -75,9 +75,9 @@ class Options {
   var $values=Array("htprefix"=>"/uwikicms",
 		    "dbprefix"=>"",
 		    "siteurl"=>"http://localhost",
-		    "dbhost"=>"server",
-		    "dbname"=>"mydb",
-		    "dbuser"=>"user",
+		    "dbhost"=>"localhost",
+		    "dbname"=>"uwikicms",
+		    "dbuser"=>"uwikicms",
 		    "dbpasswd"=>"x",
 		    "images_dir"=>"/_uwikicms/template/images/default",
 		    "css_dir"=>"/_uwikicms/template/css/default",
