@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # UWiKiCMS is a lightweight web content management system.
-# Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+# Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@ for c in ./configure ../configure; do
 done
 
 $CMD \
---siteurl="http://test.streets:8080" \
+--siteurl="http://localhost:8080" \
 --dbprefix="/perso/ufo" \
 --dbhost="$TEST_DBHOST" \
 --dbname="$TEST_DBNAME" \
