@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # UWiKiCMS is a lightweight web content management system.
-# Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+# Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -31,7 +31,7 @@ $CMD \
 --release \
 --siteurl="http://vap.ufoot.org" \
 --htprefix="" \
---dbprefix="/perso/vap" \
+--dbprefix="/more/vap" \
 --dbhost=$UFOOT_ORG_DBHOST \
 --dbname=$UFOOT_ORG_DBNAME \
 --dbuser=$UFOOT_ORG_DBUSER \
