@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -32,11 +32,10 @@ class UWC_Cache {
   var $mode="";
   var $conf=null;
   var $request=null;
-  var $lang=null;
   var $path="";
+  var $lang="";
   var $action="";
   var $cache_action="";
-  var $lang="";
   var $lang_forced=false;
   var $file="";
   var $http_code=0;
@@ -80,6 +79,7 @@ class UWC_Cache {
 	 ($action=="tree")) && 
 	(!$this->request->has_key("session")) &&
 	(!$this->request->has_key("login")) &&
+	(!$this->request->has_key("css")) &&
 	(!preg_match($this->conf->nocache_regex,$this->path))) {
       if (uwc_contextutils_is_image_page_path($this->path)) {
 	$this->cache_action="cache";
@@ -147,10 +147,13 @@ class UWC_Cache {
       uwc_contextutils_send_header_http_code($this->http_code);
       if ($this->http_code==200 && $this->is_image()) {
 	header('Content-Type: image/jpeg');
-      }
-      if ($this->http_code==200 && $this->is_xul()) {
+      } elseif ($this->http_code==200 && $this->is_xul()) {
 	header('Content-Type: application/vnd.mozilla.xul+xml');
+      } else {
+	header("Content-Language: ".$this->lang->get_lang_id());
+	header("Content-Type: text/html; charset=ISO-8859-1");
       }
+
       echo file_get_contents($this->file);
     } else {
       require("page.php");
@@ -258,4 +261,4 @@ function uwc_cache_cron($conf) {
   uwc_cache_purge($conf,$conf->cache_time);
 }
 
-?>
\ No newline at end of file
+?>
