@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@ class UWC_Content {
   var $updated=false;
   var $data_exists=false;
   var $children_updated=false;
+  var $news_updated=false;
+  var $rss_updated=false;
   var $tree_updated=false;
   var $parents_updated=false;
   var $next_updated=false;
@@ -115,9 +117,9 @@ class UWC_Content {
   }
 
   function update_children_data() {
-    $this->children=array();
     if (!$this->children_updated) {
-      $this->updated_children=true;
+      $this->children_updated=true;
+      $this->children=array();
       if ($this->get_user_status()==2) {
 	$this->data->select_content_children_by_path_lang_status_and_domain_regex($this->path,$this->lang,$this->get_user_status(),$this->get_user_domain_regex());
       } else {
@@ -132,9 +134,46 @@ class UWC_Content {
     }
   }
 
+  function update_news_data($news_max_nb, $news_max_age) {
+    $this->update_children_data();
+    if (!$this->news_updated) {
+      $this->news_updated=true;
+      $this->news=array();
+      if ($this->get_user_status()==2) {
+	$this->data->select_content_news_by_path_lang_status_and_domain_regex($this->path,$this->lang,$this->get_user_status(),$this->get_user_domain_regex(),$news_max_nb,$news_max_age);
+      } else {
+	$this->data->select_content_news_by_path_lang_and_status($this->path,$this->lang,$this->get_user_status(),$news_max_nb,$news_max_age);
+      }
+      while ($row=$this->data->query_select_fetch_row()) {
+	$item = array("path"=>$row["content_path"],
+		      "title"=>$row["content_title"]);
+	if (!in_array($item, $this->children)) {
+	  array_push($this->news, $item);
+	}
+      }
+      $this->data->query_select_free();
+    }
+  }
+
+  function update_rss_data($rss_max_nb,$rss_max_age,$rss_max_len) {
+    if (!$this->rss_updated) {
+      $this->rss_updated=true;
+      $this->rss=array();
+      $this->data->select_content_rss_by_path_and_lang($this->path,$this->lang,$rss_max_nb,$rss_max_age,$rss_max_len);
+      while ($row=$this->data->query_select_fetch_row()) {
+	array_push($this->rss, 
+		   array("path"=>$row["content_path"],
+			 "title"=>$row["content_title"],
+			 "text"=>$row["content_text"],
+			 "date_update"=>$row["content_date_update"]));
+      }
+      $this->data->query_select_free();
+    }
+  }
+
   function update_tree_data($status) {
     if (!$this->tree_updated) {
-      $this->updated_tree=true;
+      $this->tree_updated=true;
       $this->tree=array();
       if ($status>$this->get_user_status()) {
 	$status=$this->get_user_status();
@@ -246,6 +285,7 @@ class UWC_Content {
   function update_next_data() {
     if (!$this->next_updated) {
       $this->next_updated=true;
+      $this->next=null;
       if ($this->path != "") {
 	if ($this->get_user_status()==2) {
 	  $this->data->select_content_next_by_path_lang_status_and_domain_regex($this->path,$this->lang,$this->get_user_status(),$this->get_user_domain_regex(),$this->get_order());
@@ -263,6 +303,7 @@ class UWC_Content {
   function update_prev_data() {
     if (!$this->prev_updated) {
       $this->prev_updated=true;
+      $this->prev=null;
       if ($this->path != "") {
 	if ($this->get_user_status()==2) {
 	  $this->data->select_content_prev_by_path_lang_status_and_domain_regex($this->path,$this->lang,$this->get_user_status(),$this->get_user_domain_regex(),$this->get_order());
@@ -280,7 +321,7 @@ class UWC_Content {
   function update_imagelist_data() {
     if (!$this->imagelist_updated) {
       $this->imagelist_updated=true;
-      $this->imagelist=new UWC_Imagelist(& $this->data, $this->path, $this->lang);
+      $this->imagelist=new UWC_Imagelist($this->data, $this->path, $this->lang);
     }
   }
 
@@ -343,6 +384,16 @@ class UWC_Content {
     return $this->children;    
   }
 
+  function get_news($news_max_nb, $news_max_age) {
+    $this->update_news_data($news_max_nb, $news_max_age);
+    return $this->news;    
+  }
+
+  function get_rss($rss_max_nb, $rss_max_age, $rss_max_len) {
+    $this->update_rss_data($rss_max_nb, $rss_max_age, $rss_max_len);
+    return $this->rss;    
+  }
+
   function get_tree($status) {
     $this->update_tree_data($status);
     return $this->tree;    
