@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
  MA  02110-1301  USA
 */
 
-define(UWC_CONTEXT_ALLINONE_MAX_SIZE,480);
+define("UWC_CONTEXT_ALLINONE_MAX_SIZE",480);
 
 class UWC_Context {
   var $mode="";
@@ -39,7 +39,7 @@ class UWC_Context {
   var $input_height1=25;
   var $input_width2=80;
   var $input_height2=25;
-  
+  var $use_css=true;  
 
   function UWC_Context($mode,&$conf,&$data,&$lang,&$auth,&$request) {
     $this->mode=& $mode;
@@ -52,6 +52,7 @@ class UWC_Context {
     $this->update_path();
     $this->update_type();
     $this->update_lang();
+    $this->update_css();
     $this->update_continue_url();
     $this->update_session();
     $this->update_gui();
@@ -150,6 +151,15 @@ class UWC_Context {
     }
   }
 
+  function update_css() {
+    if ($this->request->has_key("css") && $this->request->get_value("css")=="no") {
+      $this->next_request["css"]="no";
+      $this->use_css=false;
+    } else {
+      $this->use_css=true;
+    }
+  }
+
   function update_continue_url () {
     if ($this->request->has_key("continue")) {
       $this->continue_url=$this->request->get_value("continue");
@@ -253,6 +263,7 @@ class UWC_Context {
 	$this->request->has_key("action")) {
       switch ($this->request->get_value("action")) {
       case "tree":
+      case "rss":
 	$this->action=$this->request->get_value("action");
 	break;
       }
@@ -385,4 +396,4 @@ class UWC_Context {
   }
 }
 
-?>
\ No newline at end of file
+?>
