@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
  MA  02110-1301  USA
 */
 
-define(UWC_FORMAT_LONGDESC_CUT, 80);
+define("UWC_FORMAT_LONGDESC_CUT", 80);
 
 function uwc_format_escape_sql($str) {
   $str=uwc_format_unescape_gpc($str);
@@ -58,7 +58,7 @@ function uwc_format_text_to_html($str) {
    * case we want to change its behavior.
    */
 
-  return uwc_format_htmlfriendly(htmlentities($str));
+  return uwc_format_htmlfriendly(htmlentities($str,ENT_COMPAT|ENT_XHTML,"ISO-8859-15"));
 }
 
 function uwc_format_html_to_xul($str) {
@@ -206,4 +206,16 @@ function uwc_format_htmlfriendly($var){
 
    return $var;
 }
-?>
+
+function uwc_format_escape_rss($var) {
+  $var = strtr($var, 
+	       array("&" => "&amp;",
+		     ">" => "&gt;",
+		     "<" => "&lt;",
+		     '"' => "&quot;",
+		     "'" => "&apos;"));
+
+  return $var;
+}
+
+?>
\ No newline at end of file
