@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -26,7 +26,7 @@
  */
 
 $GLOBALS["HORDE_BASE"]=dirname(__FILE__) . DIRECTORY_SEPARATOR . "horde";
-define(HORDE_BASE,$GLOBALS["HORDE_BASE"]);
+define("HORDE_BASE",$GLOBALS["HORDE_BASE"]);
 
 require("horde/lib/Cipher.php");
 require("horde/lib/Cipher/blowfish.php");
