@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -65,6 +65,7 @@ class UWC_Lang {
     $this->lang_id=substr($this->lang,0,2);
     $this->locale=$curgtlang;
     setlocale (LC_ALL, $this->locale);
+    $GLOBALS["LANG"]=$this->locale;
   }
 
   function include_messages() {
@@ -199,12 +200,12 @@ function uwc_lang_al2gt($gettextlangs) {
     $noct=@preg_split("/-/",$allang);
 
     $testvals=array(
-		    array($alscores[$allang], $acscores[$gtcs]),
-		    array($alscores[$noct[0]], $acscores[$gtcs]),
-		    array($alscores[$allang], $acscores["*"]),
-		    array($alscores[$noct[0]], $acscores["*"]),
-		    array($alscores["*"], $acscores[$gtcs]),
-		    array($alscores["*"], $acscores["*"]));
+		    array(array_key_exists($allang, $alscores) ? $alscores[$allang] : 0, $acscores[$gtcs]),
+		    array(array_key_exists($noct[0], $alscores) ? $alscores[$noct[0]] : 0, $acscores[$gtcs]),
+		    array(array_key_exists($allang, $alscores) ? $alscores[$allang] : 0, $acscores["*"]),
+		    array(array_key_exists($noct[0], $alscores) ? $alscores[$noct[0]] : 0, $acscores["*"]),
+		    array(array_key_exists("*", $alscores) ? $alscores["*"] : 0, $acscores[$gtcs]),
+		    array(array_key_exists("*", $alscores) ? $alscores["*"] : 0, $acscores["*"]));
 
     $found=FALSE;
     foreach($testvals as $tval) {
