@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -75,7 +75,10 @@ $this->messages=array
    "action_login"=>"Login",
    "action_logout"=>"Logout (%s)",
    "action_view"=>"View page",
+   "action_rss"=>"RSS feed",
    "action_tree"=>"Site map",
+   "action_css_yes"=>"With CSS",
+   "action_css_no"=>"Without CSS",
    "action_update"=>"Modify",
    "action_delete"=>"Delete",
    "action_new"=>"New page",
@@ -122,6 +125,7 @@ $this->messages=array
    "gallery_next"=>"Next image",
    "gallery_empty"=>"No images in this gallery",
    "google_search"=>"Google search",
+   "rss_about"=>"RSS feed for %s",
 
    "" => ""
 
