@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -75,7 +75,10 @@ $this->messages=array
    "action_login"=>"Se connecter",
    "action_logout"=>"Se d&eacute;connecter (%s)",
    "action_view"=>"Voir la page",
+   "action_rss"=>"Flux RSS",
    "action_tree"=>"Plan du site",
+   "action_css_yes"=>"Avec CSS",
+   "action_css_no"=>"Sans CSS",
    "action_update"=>"Modifier",
    "action_delete"=>"Supprimer",
    "action_new"=>"Nouvelle page",
@@ -122,6 +125,7 @@ $this->messages=array
    "gallery_next"=>"Image suivante",
    "gallery_empty"=>"Aucune image dans ce diaporama",
    "google_search"=>"Recherche Google",
+   "rss_about"=>"Flux RSS concernant %s",
 
    ""=>""
    );
