@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -40,8 +40,9 @@ require("external.php");
 require("phpwiki.php");
 require("horde.php");
 require("gallery.php");
+require("rss.php");
 
-define(UWC_PAGE_DESCRIPTION_SIZE,80);
+define("UWC_PAGE_DESCRIPTION_SIZE",80);
 
 class UWC_Page {
   var $context=false;
@@ -146,6 +147,7 @@ class UWC_Page {
       case "updateform":
       case "deleteform":
       case "view":
+      case "rss":
       case "external":
       case "imageupdateform":
       case "imagedeleteform":
@@ -267,6 +269,34 @@ class UWC_Page {
   function get_lang_height() {
     return $this->conf->lang_height;
   }
+ 
+  function get_rss_width() {
+    return $this->conf->rss_width;
+  }
+
+  function get_rss_height() {
+    return $this->conf->rss_height;
+  }
+
+  function get_news_max_nb() {
+    return $this->conf->news_max_nb;
+  }
+
+  function get_news_max_age() {
+    return $this->conf->news_max_age;
+  }
+
+  function get_rss_max_nb() {
+    return $this->conf->rss_max_nb;
+  }
+
+  function get_rss_max_age() {
+    return $this->conf->rss_max_age;
+  }
+
+  function get_rss_max_len() {
+    return $this->conf->rss_max_len;
+  }
 
   function get_status() {
     return $this->content->get_status();
@@ -351,6 +381,14 @@ class UWC_Page {
     return $this->content->get_children();
   }
 
+  function get_news() {
+    return $this->content->get_news($this->get_news_max_nb(), $this->get_news_max_age());
+  }
+
+  function get_rss() {
+    return $this->content->get_rss($this->get_rss_max_nb(), $this->get_rss_max_age(), $this->get_rss_max_len());
+  }
+
   function get_allinone_status() {
     if ($this->request->has_key("status")) {
       $status=(int) $this->request->get_value("status");
@@ -485,7 +523,11 @@ class UWC_Page {
   }
 
   function get_absolute_url_clean() {
-    return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>"","session"=>""));
+    return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>"","session"=>"","action"=>""));
+  }
+
+  function make_absolute_url_clean($path) {
+    return $this->conf->siteurl.$this->make_url($path,array("login"=>"","password"=>"","session"=>"","action"=>""));
   }
 
   function need_absolute_url() {
@@ -500,6 +542,18 @@ class UWC_Page {
     return $this->make_url($this->get_path(),array("action"=>"tree"));
   }
 
+  function get_rss_url() {
+    return $this->make_url($this->get_path(),array("action"=>"rss"));
+  }
+
+  function get_css_yes_url() {
+    return $this->make_url($this->get_path(),array("css"=>"yes"));
+  }
+
+  function get_css_no_url() {
+    return $this->make_url($this->get_path(),array("css"=>"no"));
+  }
+
   function get_new_url() {
     return $this->make_url("/_uwikicms/new.php",array("lang"=>$this->get_lang()));
   }
@@ -565,7 +619,7 @@ class UWC_Page {
   }
 
   function get_imagenew_url() {
-    return $this->make_url(uwc_image_make_page_url($this->get_path(),uwc_image_get_next_id(&$this->data)),array("lang"=>$this->get_lang()));
+    return $this->make_url(uwc_image_make_page_url($this->get_path(),uwc_image_get_next_id($this->data)),array("lang"=>$this->get_lang()));
   }
 
   function get_imagecreate_url() {
@@ -682,7 +736,7 @@ class UWC_Page {
   }
 
   function make_url($path,$params=false) {
-    return htmlentities($this->make_url_no_esc($path,$params));
+    return htmlentities($this->make_url_no_esc($path,$params),ENT_COMPAT|ENT_XHTML,"ISO-8859-15");
   }
 
   function make_img_link($image_id,$linkname) { 
@@ -788,7 +842,7 @@ class UWC_Page {
   }
 
   function get_meta_description() {
-    return $this->translate1("meta_description",$this->get_title());
+    return $this->get_home_title();
   }
 
   function get_meta_keywords() {
@@ -883,10 +937,22 @@ class UWC_Page {
     return $this->context->action!="view" && $this->context->action!="external" && $this->context->action!="imageview" && $this->viewable();
   }
 
+  function need_action_rss() {
+    return $this->need_rss();
+  }
+
   function need_action_tree() {
     return $this->context->action!="tree" && $this->viewable() && $this->need_children();
   }
 
+  function need_action_css_no() {
+    return $this->context->use_css && !$this->need_action_view();
+  }
+
+  function need_action_css_yes() {
+    return !$this->context->use_css && !$this->need_action_view();
+  }
+
   function need_action_update() {
     return $this->context->action!="updateform" && $this->editable();
   }
@@ -936,8 +1002,16 @@ class UWC_Page {
     return count($this->get_children()) ? true : false;
   }
 
+  function need_news() {
+    return count($this->get_news()) ? true : false;
+  }
+
+  function need_rss() {
+    return count($this->get_rss()) ? true : false;
+  }
+
   function need_nav() {
-    return $this->need_home() || $this->need_up() || $this->need_next() || $this->need_prev();
+    return $this->need_home() || $this->need_up() || $this->need_next() || $this->need_prev() || $this->need_news();
   }
 
   function need_home() {
@@ -964,6 +1038,22 @@ class UWC_Page {
     uwc_external_include($this);
   }
 
+  function need_control_focus() {
+    return $this->conf->control_focus ? true : false;
+  }
+
+  function get_control_focus() {
+    return $this->conf->control_focus;
+  }
+
+  function need_actions_focus() {
+    return $this->conf->actions_focus ? true : false;
+  }
+
+  function get_actions_focus() {
+    return $this->conf->actions_focus;
+  }
+
   function set_http_code($http_code) {
     $this->http_code=(int) $http_code;
     uwc_contextutils_send_header_http_code($this->get_http_code());
@@ -981,6 +1071,10 @@ class UWC_Page {
     return $http_code;
   }
 
+  function use_css() {
+    return $this->context->use_css;
+  }
+
   function process() {
     switch ($this->context->action) {
     case "logout":
@@ -1087,16 +1181,23 @@ class UWC_Page {
 
     switch ($this->context->action) {
     case "imageviewpreview":
-      uwc_imagebinary_view_preview(& $this->data,$this->context->get_image_id());
+      uwc_imagebinary_view_preview($this->data,$this->context->get_image_id());
       break;
     case "imageviewfull":
-      uwc_imagebinary_view_full(& $this->data,$this->context->get_image_id());
+      uwc_imagebinary_view_full($this->data,$this->context->get_image_id());
       break;
     case "gallery":
       uwc_gallery_xul_header();
       include $this->get_prefix()."/_uwikicms/template/php/".$this->context->action.".php";
       break;
+    case "rss":
+      uwc_rss_xml_header();
+      include $this->get_prefix()."/_uwikicms/template/php/".$this->context->action.".php";
+      break;
     default:
+      header("Content-Language: ".$this->get_lang());
+      header("Content-Type: text/html; charset=ISO-8859-1");
+
       /*
        * General case, we use the template system.
        */
