@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -54,7 +54,11 @@ class UWC_Request {
   }
 
   function get_value($key) {
-    return $this->request[$key];
+    if ($this->has_key($key)) {
+      return $this->request[$key];
+    } else {
+      return "";
+    }
   }
 
   function get_request_uri() {
