@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -19,16 +19,16 @@
  MA  02110-1301  USA
 */
 ?>
-<form method="post" action="<? echo $this->get_clearcache_url(); ?>">
+<form method="post" action="<?php echo $this->get_clearcache_url(); ?>">
 
 <div id="message" class="default">
 <div>
-<? echo $this->translate("confirm_clear_cache"); ?>
+<?php echo $this->translate("confirm_clear_cache"); ?>
 </div>
 
 <div>
-<input type="hidden" name="path" value="<? echo $this->get_path(); ?>" />
-<input type="submit" name="submit" value="<? echo $this->translate("clear_cache"); ?>" class="button" />
+<input type="hidden" name="path" value="<?php echo $this->get_path(); ?>" />
+<input type="submit" name="submit" value="<?php echo $this->translate("clear_cache"); ?>" class="button" />
 </div>
 </div>
 
