@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -20,11 +20,11 @@
 */
 ?>
 <div id="message" class="default">
-<? echo $this->translate("doc_created"); ?>.
+<?php echo $this->translate("doc_created"); ?>.
 </div>
 
-<div id="content" class="<? echo $this->get_status_style(); ?>">
-<? echo $this->get_text(); ?>
+<div id="content" class="<?php echo $this->get_status_style(); ?>">
+<?php echo $this->get_text(); ?>
 </div>
 
 
