@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -20,5 +20,5 @@
 */
 ?>
 <div id="message" class="default">
-<? echo $this->translate("doc_deleted"); ?>.
+<?php echo $this->translate("doc_deleted"); ?>.
 </div>
