@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -19,19 +19,19 @@
  MA  02110-1301  USA
 */
 ?>
-<div id="content" class="<? echo $this->get_status_style(); ?>">
+<div id="content" class="<?php echo $this->get_status_style(); ?>">
 
 <div class="image">
 <div>
-<a href="<? echo $this->get_image_full_url(); ?>"><img src="<? echo $this->get_image_full_url(); ?>" width="<? echo $this->get_image_fullscaled_w(); ?>" height="<? echo $this->get_image_fullscaled_h(); ?>" alt="<? echo $this->get_legend_alt(); ?>" class="msiehackimage" /></a>
+<a href="<?php echo $this->get_image_full_url(); ?>"><img src="<?php echo $this->get_image_full_url(); ?>" width="<?php echo $this->get_image_fullscaled_w(); ?>" height="<?php echo $this->get_image_fullscaled_h(); ?>" alt="<?php echo $this->get_legend_alt(); ?>" class="msiehackimage" /></a>
 </div>
 <div>
-<? echo $this->translate4("filename_width_height_size",$this->get_image_filename(),$this->get_image_full_w(),$this->get_image_full_h(),$this->get_image_size()); ?>
+<?php echo $this->translate4("filename_width_height_size",$this->get_image_filename(),$this->get_image_full_w(),$this->get_image_full_h(),$this->get_image_size()); ?>
 </div>
 </div>
 
 <div>
-<? echo $this->get_legend_longdesc(); ?>
+<?php echo $this->get_legend_longdesc(); ?>
 </div>
 
 </div>
