@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -21,13 +21,13 @@
 ?>
 <div id="message" class="default">
 <div>
-<?echo $this->translate("logout_success"); ?>
+<?php echo $this->translate("logout_success"); ?>
 </div>
 
-<? if ($this->need_continue_url()) { ?>
+<?php if ($this->need_continue_url()) { ?>
 <div>
-     <a href="<? echo $this->make_url($this->get_continue_url()); ?>"><? echo $this->translate("continue"); ?></a>
+     <a href="<?php echo $this->make_url($this->get_continue_url()); ?>"><?php echo $this->translate("continue"); ?></a>
 </div>
-<? } ?>
+<?php } ?>
 </div>
 
